KeeperAction

Enum KeeperAction 

#[repr(u8)]
pub enum KeeperAction<Address> { UpdateOraclePrices { prices: Vec<OraclePriceUpdateArgs>, publish_timestamp: UnixTimestampMicros, }, UpdateMarkPrices { prices: Vec<MarkPriceUpdateArgs>, publish_timestamp: UnixTimestampMicros, }, UpdatePremiumIndexes { market_ids: Vec<MarketId>, }, UpdateFunding { market_ids: Vec<MarketId>, }, AddTradingCredits { user_address: Address, amount: PositiveDecimal, }, RemoveTradingCredits { user_address: Address, amount: PositiveDecimal, }, UpdateUserFeeTier { address: Address, fee_tier: FeeTier, }, UpdateUserFeeDiscountBps { address: Address, fee_discount_bps: u16, }, SetCumulativeReferralRewards { address: Address, asset_id: AssetId, amount: PositiveDecimal, }, }
Keeper operations requiring specific admin privileges.

These operations are typically called by automated keepers/bots and require specific admin types (Pricing, Funding, Credits, FeeTier, Referrals). However, one can also update all admin addresses with it.

Variants



UpdateOraclePrices

Update oracle prices (PricingAdmin).

Fields

publish_timestamp: UnixTimestampMicros


UpdateMarkPrices

Update mark prices (PricingAdmin).

Fields

publish_timestamp: UnixTimestampMicros


UpdatePremiumIndexes

Update premium indexes for markets (PricingAdmin).

Fields

market_ids: Vec<MarketId>


UpdateFunding

Update funding rates for markets (FundingAdmin).

Fields

market_ids: Vec<MarketId>


AddTradingCredits

Add trading credits to a user (CreditsAdmin).

Fields

user_address: Address


RemoveTradingCredits

Remove trading credits from a user (CreditsAdmin).

Fields

user_address: Address


UpdateUserFeeTier

Update user’s fee tier (FeeTierAdmin).

Fields

address: Address
fee_tier: FeeTier


UpdateUserFeeDiscountBps

Update a given user’s fee discount (in bps) (FeeTierAdmin).

Fields

address: Address
fee_discount_bps: u16


SetCumulativeReferralRewards

Set a user’s cumulative referral rewards to an absolute amount (ReferralsAdmin).

Fields

address: Address
asset_id: AssetId

Implementations

Source

impl<Address> KeeperAction<Address>

pub fn required_admin_type(&self) -> AdminType

Returns the specific admin type required for this keeper operation.