pub struct CreateVaultArgs<Address> {
pub name: CustomString,
pub description: CustomString,
pub leader: Address,
pub deposit_asset_ids: Vec<AssetId>,
pub withdraw_asset_id: AssetId,
pub withdraw_lockup_period_hours: u8,
pub whitelist_deposits: bool,
pub profit_share_percentage: u8,
pub withdrawal_fee_bps: u8,
pub deposit_limit: PositiveDecimal,
}Fields
name: CustomStringdescription: CustomStringleader: Addressdeposit_asset_ids: Vec<AssetId>withdraw_asset_id: AssetIdwithdraw_lockup_period_hours: u8whitelist_deposits: boolwithdrawal_fee_bps: u8deposit_limit: PositiveDecimalTrait Implementations
Sourceimpl<Address> BorshDeserialize for CreateVaultArgs<Address>where
Address: BorshDeserialize,
impl<Address> BorshDeserialize for CreateVaultArgs<Address>where
Address: BorshDeserialize,
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<Address> BorshSerialize for CreateVaultArgs<Address>where
Address: BorshSerialize,
impl<Address> BorshSerialize for CreateVaultArgs<Address>where
Address: BorshSerialize,
Sourceimpl<Address: Clone> Clone for CreateVaultArgs<Address>
impl<Address: Clone> Clone for CreateVaultArgs<Address>
Sourcefn clone(&self) -> CreateVaultArgs<Address>
fn clone(&self) -> CreateVaultArgs<Address>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<Address: Debug> Debug for CreateVaultArgs<Address>
impl<Address: Debug> Debug for CreateVaultArgs<Address>
Sourceimpl<'de, Address> Deserialize<'de> for CreateVaultArgs<Address>where
Address: Deserialize<'de>,
impl<'de, Address> Deserialize<'de> for CreateVaultArgs<Address>where
Address: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<Address: Hash> Hash for CreateVaultArgs<Address>
impl<Address: Hash> Hash for CreateVaultArgs<Address>
Sourceimpl<Address: JsonSchema> JsonSchema for CreateVaultArgs<Address>
impl<Address: JsonSchema> JsonSchema for CreateVaultArgs<Address>
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<Address: Ord> Ord for CreateVaultArgs<Address>
impl<Address: Ord> Ord for CreateVaultArgs<Address>
Sourcefn cmp(&self, other: &CreateVaultArgs<Address>) -> Ordering
fn cmp(&self, other: &CreateVaultArgs<Address>) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<Address: PartialEq> PartialEq for CreateVaultArgs<Address>
impl<Address: PartialEq> PartialEq for CreateVaultArgs<Address>
Sourceimpl<Address: PartialOrd> PartialOrd for CreateVaultArgs<Address>
impl<Address: PartialOrd> PartialOrd for CreateVaultArgs<Address>
Sourceimpl<Address> Serialize for CreateVaultArgs<Address>where
Address: Serialize,
impl<Address> Serialize for CreateVaultArgs<Address>where
Address: Serialize,
impl<Address: Eq> Eq for CreateVaultArgs<Address>
impl<Address> StructuralPartialEq for CreateVaultArgs<Address>