pub struct InitPerpMarketArgs {Show 22 fields
pub market_id: MarketId,
pub base_asset_id: AssetId,
pub name: CustomString,
pub trading_mode: TradingMode,
pub min_tick_size: PositiveDecimal,
pub min_lot_size: PositiveDecimal,
pub max_orders_per_side: u16,
pub max_orders_per_user: u16,
pub max_trigger_orders_per_user: u16,
pub min_interest_rate_clamp: SurrogateDecimal,
pub max_interest_rate_clamp: SurrogateDecimal,
pub min_funding_rate_clamp: SurrogateDecimal,
pub max_funding_rate_clamp: SurrogateDecimal,
pub max_oi_notional: PositiveDecimal,
pub max_order_to_mark_price_deviation_ratio: PositiveDecimal,
pub max_trigger_to_comparison_price_deviation_ratio: PositiveDecimal,
pub max_order_to_trigger_price_deviation_ratio: PositiveDecimal,
pub impact_margin: PositiveDecimal,
pub interest_rate: SurrogateDecimal,
pub leverage_table_args: SurrogateLeverageTableArgs,
pub taker_fees_tenth_bps: Vec<i16>,
pub maker_fees_tenth_bps: Vec<i16>,
}Fields
market_id: MarketIdbase_asset_id: AssetIdname: CustomStringtrading_mode: TradingModemin_tick_size: PositiveDecimalmin_lot_size: PositiveDecimalmax_orders_per_side: u16max_orders_per_user: u16max_trigger_orders_per_user: u16min_interest_rate_clamp: SurrogateDecimalmax_interest_rate_clamp: SurrogateDecimalmin_funding_rate_clamp: SurrogateDecimalmax_funding_rate_clamp: SurrogateDecimalmax_oi_notional: PositiveDecimalmax_order_to_mark_price_deviation_ratio: PositiveDecimalmax_trigger_to_comparison_price_deviation_ratio: PositiveDecimalmax_order_to_trigger_price_deviation_ratio: PositiveDecimalimpact_margin: PositiveDecimalinterest_rate: SurrogateDecimalleverage_table_args: SurrogateLeverageTableArgstaker_fees_tenth_bps: Vec<i16>maker_fees_tenth_bps: Vec<i16>Trait Implementations
Sourceimpl BorshDeserialize for InitPerpMarketArgs
impl BorshDeserialize for InitPerpMarketArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InitPerpMarketArgs
impl BorshSerialize for InitPerpMarketArgs
Sourceimpl Clone for InitPerpMarketArgs
impl Clone for InitPerpMarketArgs
Sourcefn clone(&self) -> InitPerpMarketArgs
fn clone(&self) -> InitPerpMarketArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InitPerpMarketArgs
impl Debug for InitPerpMarketArgs
Sourceimpl<'de> Deserialize<'de> for InitPerpMarketArgs
impl<'de> Deserialize<'de> for InitPerpMarketArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for InitPerpMarketArgs
impl Hash for InitPerpMarketArgs
Sourceimpl JsonSchema for InitPerpMarketArgs
impl JsonSchema for InitPerpMarketArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for InitPerpMarketArgs
impl Ord for InitPerpMarketArgs
Sourcefn cmp(&self, other: &InitPerpMarketArgs) -> Ordering
fn cmp(&self, other: &InitPerpMarketArgs) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InitPerpMarketArgs
impl PartialEq for InitPerpMarketArgs
Sourcefn eq(&self, other: &InitPerpMarketArgs) -> bool
fn eq(&self, other: &InitPerpMarketArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for InitPerpMarketArgs
impl PartialOrd for InitPerpMarketArgs
Sourceimpl Serialize for InitPerpMarketArgs
impl Serialize for InitPerpMarketArgs
Sourceimpl UniversalWallet for InitPerpMarketArgs
impl UniversalWallet for InitPerpMarketArgs
Sourcefn scaffold() -> Item<IndexLinking>
fn scaffold() -> Item<IndexLinking>
Generate the “scaffolding” of the item. If the item is a primtive, this is just the corresponding primtive.
If the type is composed of other types, this is the container with all links set to
Link::Placeholder.Sourcefn get_child_links(schema: &mut Schema) -> Vec<Link>
fn get_child_links(schema: &mut Schema) -> Vec<Link>
Ensure that each type contained in the outer type (i.e. the type of each struct/tuple field) is added to the schema,
and return a
Link connecting the child to the parent. Read moreSourcefn get_child_templates(schema: &mut Schema) -> TransactionTemplateSet
fn get_child_templates(schema: &mut Schema) -> TransactionTemplateSet
Empty by default
When derived by the macro, builds a template set from annotations on the fields + the field
types’ own get_child_templates()
Sourcefn write_schema(schema: &mut Schema) -> Link
fn write_schema(schema: &mut Schema) -> Link
Writes the type to the schema if it is not already present and returns a link to it. Read more
Sourcefn make_root_of(schema: &mut Schema)
fn make_root_of(schema: &mut Schema)
Writes the type and all its children to the schema, if not already present, and sets the
type as a root type. Generates any templates defined on that type.
Sourcefn make_linkable(schema: &mut Schema) -> Link
fn make_linkable(schema: &mut Schema) -> Link
Gets a link to the type, writing the type to the schema if necessary.
Sourcefn id_override() -> Option<ItemId>
fn id_override() -> Option<ItemId>
Override the type ID of the item. This should typically not be written by hand. Instead,
use the
OverrideSchema trait.impl Eq for InitPerpMarketArgs
impl StructuralPartialEq for InitPerpMarketArgs