pub struct NewOrderArgs {
pub price: PositiveDecimal,
pub size: PositiveDecimal,
pub side: Side,
pub order_type: OrderType,
pub reduce_only: bool,
pub client_order_id: Option<ClientOrderId>,
pub pending_tpsl_pair: Option<PendingTpslPair>,
}Fields
price: PositiveDecimalsize: PositiveDecimalside: Sideorder_type: OrderTypereduce_only: boolclient_order_id: Option<ClientOrderId>pending_tpsl_pair: Option<PendingTpslPair>Trait Implementations
Sourceimpl BorshDeserialize for NewOrderArgs
impl BorshDeserialize for NewOrderArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for NewOrderArgs
impl BorshSerialize for NewOrderArgs
Sourceimpl Clone for NewOrderArgs
impl Clone for NewOrderArgs
Sourcefn clone(&self) -> NewOrderArgs
fn clone(&self) -> NewOrderArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NewOrderArgs
impl Debug for NewOrderArgs
Sourceimpl<'de> Deserialize<'de> for NewOrderArgs
impl<'de> Deserialize<'de> for NewOrderArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for NewOrderArgs
impl Hash for NewOrderArgs
Sourceimpl JsonSchema for NewOrderArgs
impl JsonSchema for NewOrderArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for NewOrderArgs
impl Ord for NewOrderArgs
Sourcefn cmp(&self, other: &NewOrderArgs) -> Ordering
fn cmp(&self, other: &NewOrderArgs) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for NewOrderArgs
impl PartialEq for NewOrderArgs
Sourceimpl PartialOrd for NewOrderArgs
impl PartialOrd for NewOrderArgs
Sourceimpl Serialize for NewOrderArgs
impl Serialize for NewOrderArgs
impl Eq for NewOrderArgs
impl StructuralPartialEq for NewOrderArgs