pub struct UpdateGlobalConfigArgs<Address> {
pub max_orders_per_user: Option<u16>,
pub max_trigger_orders_per_user: Option<u16>,
pub max_orders_per_batch_msg: Option<u16>,
pub max_trigger_orders_to_execute_per_msg: Option<u16>,
pub min_notional_twap_value: Option<PositiveDecimal>,
pub min_notional_twap_value_per_order: Option<PositiveDecimal>,
pub twap_execution_interval_seconds: Option<u64>,
pub deposit_limits_per_user: Option<Vec<(AssetId, PositiveDecimal)>>,
pub whitelisted_users_for_deposit: Option<Vec<Address>>,
}Fields
max_orders_per_user: Option<u16>max_trigger_orders_per_user: Option<u16>max_orders_per_batch_msg: Option<u16>max_trigger_orders_to_execute_per_msg: Option<u16>min_notional_twap_value: Option<PositiveDecimal>min_notional_twap_value_per_order: Option<PositiveDecimal>twap_execution_interval_seconds: Option<u64>deposit_limits_per_user: Option<Vec<(AssetId, PositiveDecimal)>>whitelisted_users_for_deposit: Option<Vec<Address>>Trait Implementations
Sourceimpl<Address> BorshDeserialize for UpdateGlobalConfigArgs<Address>where
Address: BorshDeserialize,
impl<Address> BorshDeserialize for UpdateGlobalConfigArgs<Address>where
Address: BorshDeserialize,
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<Address> BorshSerialize for UpdateGlobalConfigArgs<Address>where
Address: BorshSerialize,
impl<Address> BorshSerialize for UpdateGlobalConfigArgs<Address>where
Address: BorshSerialize,
Sourceimpl<Address: Clone> Clone for UpdateGlobalConfigArgs<Address>
impl<Address: Clone> Clone for UpdateGlobalConfigArgs<Address>
Sourcefn clone(&self) -> UpdateGlobalConfigArgs<Address>
fn clone(&self) -> UpdateGlobalConfigArgs<Address>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<Address: Debug> Debug for UpdateGlobalConfigArgs<Address>
impl<Address: Debug> Debug for UpdateGlobalConfigArgs<Address>
Sourceimpl<'de, Address> Deserialize<'de> for UpdateGlobalConfigArgs<Address>where
Address: Deserialize<'de>,
impl<'de, Address> Deserialize<'de> for UpdateGlobalConfigArgs<Address>where
Address: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<Address: Hash> Hash for UpdateGlobalConfigArgs<Address>
impl<Address: Hash> Hash for UpdateGlobalConfigArgs<Address>
Sourceimpl<Address: JsonSchema> JsonSchema for UpdateGlobalConfigArgs<Address>
impl<Address: JsonSchema> JsonSchema for UpdateGlobalConfigArgs<Address>
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<Address: Ord> Ord for UpdateGlobalConfigArgs<Address>
impl<Address: Ord> Ord for UpdateGlobalConfigArgs<Address>
Sourcefn cmp(&self, other: &UpdateGlobalConfigArgs<Address>) -> Ordering
fn cmp(&self, other: &UpdateGlobalConfigArgs<Address>) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<Address: PartialEq> PartialEq for UpdateGlobalConfigArgs<Address>
impl<Address: PartialEq> PartialEq for UpdateGlobalConfigArgs<Address>
Sourcefn eq(&self, other: &UpdateGlobalConfigArgs<Address>) -> bool
fn eq(&self, other: &UpdateGlobalConfigArgs<Address>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<Address: PartialOrd> PartialOrd for UpdateGlobalConfigArgs<Address>
impl<Address: PartialOrd> PartialOrd for UpdateGlobalConfigArgs<Address>
Sourceimpl<Address> Serialize for UpdateGlobalConfigArgs<Address>where
Address: Serialize,
impl<Address> Serialize for UpdateGlobalConfigArgs<Address>where
Address: Serialize,
impl<Address: Eq> Eq for UpdateGlobalConfigArgs<Address>
impl<Address> StructuralPartialEq for UpdateGlobalConfigArgs<Address>