pub struct UpdatePerpLiquidationConfigArgs {
pub liquidation_fee: Option<PositiveDecimal>,
pub liquidation_ioc_buffer: Option<PositiveDecimal>,
pub backstop_liquidation_threshold: Option<PositiveDecimal>,
pub liquidation_protocol_reward_ratio: Option<PositiveDecimal>,
}Fields
liquidation_fee: Option<PositiveDecimal>liquidation_ioc_buffer: Option<PositiveDecimal>backstop_liquidation_threshold: Option<PositiveDecimal>liquidation_protocol_reward_ratio: Option<PositiveDecimal>Trait Implementations
Sourceimpl BorshDeserialize for UpdatePerpLiquidationConfigArgs
impl BorshDeserialize for UpdatePerpLiquidationConfigArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdatePerpLiquidationConfigArgs
impl Clone for UpdatePerpLiquidationConfigArgs
Sourcefn clone(&self) -> UpdatePerpLiquidationConfigArgs
fn clone(&self) -> UpdatePerpLiquidationConfigArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for UpdatePerpLiquidationConfigArgs
impl<'de> Deserialize<'de> for UpdatePerpLiquidationConfigArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UpdatePerpLiquidationConfigArgs
impl JsonSchema for UpdatePerpLiquidationConfigArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for UpdatePerpLiquidationConfigArgs
impl Ord for UpdatePerpLiquidationConfigArgs
Sourcefn cmp(&self, other: &UpdatePerpLiquidationConfigArgs) -> Ordering
fn cmp(&self, other: &UpdatePerpLiquidationConfigArgs) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UpdatePerpLiquidationConfigArgs
impl PartialEq for UpdatePerpLiquidationConfigArgs
Sourcefn eq(&self, other: &UpdatePerpLiquidationConfigArgs) -> bool
fn eq(&self, other: &UpdatePerpLiquidationConfigArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UpdatePerpLiquidationConfigArgs
impl PartialOrd for UpdatePerpLiquidationConfigArgs
Sourceimpl UniversalWallet for UpdatePerpLiquidationConfigArgs
impl UniversalWallet for UpdatePerpLiquidationConfigArgs
Sourcefn scaffold() -> Item<IndexLinking>
fn scaffold() -> Item<IndexLinking>
Generate the “scaffolding” of the item. If the item is a primtive, this is just the corresponding primtive.
If the type is composed of other types, this is the container with all links set to
Link::Placeholder.Sourcefn get_child_links(schema: &mut Schema) -> Vec<Link>
fn get_child_links(schema: &mut Schema) -> Vec<Link>
Ensure that each type contained in the outer type (i.e. the type of each struct/tuple field) is added to the schema,
and return a
Link connecting the child to the parent. Read moreSourcefn get_child_templates(schema: &mut Schema) -> TransactionTemplateSet
fn get_child_templates(schema: &mut Schema) -> TransactionTemplateSet
Empty by default
When derived by the macro, builds a template set from annotations on the fields + the field
types’ own get_child_templates()
Sourcefn write_schema(schema: &mut Schema) -> Link
fn write_schema(schema: &mut Schema) -> Link
Writes the type to the schema if it is not already present and returns a link to it. Read more
Sourcefn make_root_of(schema: &mut Schema)
fn make_root_of(schema: &mut Schema)
Writes the type and all its children to the schema, if not already present, and sets the
type as a root type. Generates any templates defined on that type.
Sourcefn make_linkable(schema: &mut Schema) -> Link
fn make_linkable(schema: &mut Schema) -> Link
Gets a link to the type, writing the type to the schema if necessary.
Sourcefn id_override() -> Option<ItemId>
fn id_override() -> Option<ItemId>
Override the type ID of the item. This should typically not be written by hand. Instead,
use the
OverrideSchema trait.impl Eq for UpdatePerpLiquidationConfigArgs
impl StructuralPartialEq for UpdatePerpLiquidationConfigArgs