pub struct ClientOrderId(pub u64);Tuple Fields
0: u64Trait Implementations
Sourceimpl BorshDeserialize for ClientOrderId
impl BorshDeserialize for ClientOrderId
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ClientOrderId
impl BorshSerialize for ClientOrderId
Sourceimpl Clone for ClientOrderId
impl Clone for ClientOrderId
Sourcefn clone(&self) -> ClientOrderId
fn clone(&self) -> ClientOrderId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientOrderId
impl Debug for ClientOrderId
Sourceimpl Default for ClientOrderId
impl Default for ClientOrderId
Sourcefn default() -> ClientOrderId
fn default() -> ClientOrderId
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ClientOrderId
impl<'de> Deserialize<'de> for ClientOrderId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ClientOrderId
impl Display for ClientOrderId
Sourceimpl FromStr for ClientOrderId
impl FromStr for ClientOrderId
Sourceimpl Hash for ClientOrderId
impl Hash for ClientOrderId
Sourceimpl JsonSchema for ClientOrderId
impl JsonSchema for ClientOrderId
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourceimpl Ord for ClientOrderId
impl Ord for ClientOrderId
Sourcefn cmp(&self, other: &ClientOrderId) -> Ordering
fn cmp(&self, other: &ClientOrderId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClientOrderId
impl PartialEq for ClientOrderId
Sourceimpl PartialOrd for ClientOrderId
impl PartialOrd for ClientOrderId
Sourceimpl Serialize for ClientOrderId
impl Serialize for ClientOrderId
impl Copy for ClientOrderId
impl Eq for ClientOrderId
impl StructuralPartialEq for ClientOrderId