pub struct MarkPriceUpdateArgs {
pub market_id: MarketId,
pub median_cex_price: PositiveDecimal,
pub diff_ema: SurrogateDecimal,
}Fields
market_id: MarketIdmedian_cex_price: PositiveDecimaldiff_ema: SurrogateDecimalTrait Implementations
Sourceimpl BorshDeserialize for MarkPriceUpdateArgs
impl BorshDeserialize for MarkPriceUpdateArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MarkPriceUpdateArgs
impl BorshSerialize for MarkPriceUpdateArgs
Sourceimpl Clone for MarkPriceUpdateArgs
impl Clone for MarkPriceUpdateArgs
Sourcefn clone(&self) -> MarkPriceUpdateArgs
fn clone(&self) -> MarkPriceUpdateArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MarkPriceUpdateArgs
impl Debug for MarkPriceUpdateArgs
Sourceimpl<'de> Deserialize<'de> for MarkPriceUpdateArgs
impl<'de> Deserialize<'de> for MarkPriceUpdateArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for MarkPriceUpdateArgs
impl Hash for MarkPriceUpdateArgs
Sourceimpl JsonSchema for MarkPriceUpdateArgs
impl JsonSchema for MarkPriceUpdateArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for MarkPriceUpdateArgs
impl Ord for MarkPriceUpdateArgs
Sourcefn cmp(&self, other: &MarkPriceUpdateArgs) -> Ordering
fn cmp(&self, other: &MarkPriceUpdateArgs) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MarkPriceUpdateArgs
impl PartialEq for MarkPriceUpdateArgs
Sourceimpl PartialOrd for MarkPriceUpdateArgs
impl PartialOrd for MarkPriceUpdateArgs
Sourceimpl Serialize for MarkPriceUpdateArgs
impl Serialize for MarkPriceUpdateArgs
impl Eq for MarkPriceUpdateArgs
impl StructuralPartialEq for MarkPriceUpdateArgs