pub struct OraclePriceUpdateArgs {
pub asset_id: AssetId,
pub oracle_price: PositiveDecimal,
}Fields
asset_id: AssetIdoracle_price: PositiveDecimalTrait Implementations
Sourceimpl BorshDeserialize for OraclePriceUpdateArgs
impl BorshDeserialize for OraclePriceUpdateArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for OraclePriceUpdateArgs
impl Clone for OraclePriceUpdateArgs
Sourcefn clone(&self) -> OraclePriceUpdateArgs
fn clone(&self) -> OraclePriceUpdateArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OraclePriceUpdateArgs
impl Debug for OraclePriceUpdateArgs
Sourceimpl<'de> Deserialize<'de> for OraclePriceUpdateArgs
impl<'de> Deserialize<'de> for OraclePriceUpdateArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for OraclePriceUpdateArgs
impl Hash for OraclePriceUpdateArgs
Sourceimpl JsonSchema for OraclePriceUpdateArgs
impl JsonSchema for OraclePriceUpdateArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for OraclePriceUpdateArgs
impl Ord for OraclePriceUpdateArgs
Sourcefn cmp(&self, other: &OraclePriceUpdateArgs) -> Ordering
fn cmp(&self, other: &OraclePriceUpdateArgs) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OraclePriceUpdateArgs
impl PartialEq for OraclePriceUpdateArgs
Sourceimpl PartialOrd for OraclePriceUpdateArgs
impl PartialOrd for OraclePriceUpdateArgs
Sourceimpl Serialize for OraclePriceUpdateArgs
impl Serialize for OraclePriceUpdateArgs
impl Eq for OraclePriceUpdateArgs
impl StructuralPartialEq for OraclePriceUpdateArgs