pub struct TriggerOrderId(pub u64);Tuple Fields
0: u64Trait Implementations
Sourceimpl BorshDeserialize for TriggerOrderId
impl BorshDeserialize for TriggerOrderId
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TriggerOrderId
impl BorshSerialize for TriggerOrderId
Sourceimpl Clone for TriggerOrderId
impl Clone for TriggerOrderId
Sourcefn clone(&self) -> TriggerOrderId
fn clone(&self) -> TriggerOrderId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TriggerOrderId
impl Debug for TriggerOrderId
Sourceimpl Default for TriggerOrderId
impl Default for TriggerOrderId
Sourcefn default() -> TriggerOrderId
fn default() -> TriggerOrderId
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TriggerOrderId
impl<'de> Deserialize<'de> for TriggerOrderId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for TriggerOrderId
impl Display for TriggerOrderId
Sourceimpl FromStr for TriggerOrderId
impl FromStr for TriggerOrderId
Sourceimpl Hash for TriggerOrderId
impl Hash for TriggerOrderId
Sourceimpl JsonSchema for TriggerOrderId
impl JsonSchema for TriggerOrderId
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourceimpl Ord for TriggerOrderId
impl Ord for TriggerOrderId
Sourcefn cmp(&self, other: &TriggerOrderId) -> Ordering
fn cmp(&self, other: &TriggerOrderId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TriggerOrderId
impl PartialEq for TriggerOrderId
Sourceimpl PartialOrd for TriggerOrderId
impl PartialOrd for TriggerOrderId
Sourceimpl Serialize for TriggerOrderId
impl Serialize for TriggerOrderId
impl Copy for TriggerOrderId
impl Eq for TriggerOrderId
impl StructuralPartialEq for TriggerOrderId